==> senior_design_system-0.21.4.tar.gz: example/lib/pages/draggable_list.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';

class DraggableListExample extends StatelessWidget {
  const DraggableListExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    List<SeniorDraggableItem> items = [
      SeniorDraggableItem(
        key: Key('1'),
        color: SeniorColors.manchesterColorOrange,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Primeiro item',
      ),
      SeniorDraggableItem(
        key: Key('2'),
        color: SeniorColors.manchesterColorBlue,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Segundo item',
      ),
      SeniorDraggableItem(
        key: Key('3'),
        color: SeniorColors.manchesterColorGreen,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Terceiro item',
      ),
      SeniorDraggableItem(
        key: Key('4'),
        color: SeniorColors.secondaryColor800,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Quarto item',
      ),
    ];

    return PageWrapper(
      title: 'Draggable List',
      child: Center(
        child: SeniorDraggableList(
          padding: EdgeInsets.symmetric(
            horizontal: SeniorSpacing.small,
            vertical: SeniorSpacing.xsmall,
          ),
          items: items,
        ),
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/draggable_list.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';

class DraggableListExample extends StatelessWidget {
  const DraggableListExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final List<SeniorDraggableItem> items = [
      const SeniorDraggableItem(
        key: Key('1'),
        color: SeniorColors.manchesterColorOrange,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Primeiro item',
      ),
      const SeniorDraggableItem(
        key: Key('2'),
        color: SeniorColors.manchesterColorBlue,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Segundo item',
      ),
      const SeniorDraggableItem(
        key: Key('3'),
        color: SeniorColors.manchesterColorGreen,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Terceiro item',
      ),
      const SeniorDraggableItem(
        key: Key('4'),
        color: SeniorColors.secondaryColor800,
        iconColor: SeniorColors.pureWhite,
        textColor: SeniorColors.pureWhite,
        text: 'Quarto item',
      ),
    ];

    return PageWrapper(
      title: 'Draggable List',
      child: Center(
        child: SeniorDraggableList(
          padding: const EdgeInsets.symmetric(
            horizontal: SeniorSpacing.small,
            vertical: SeniorSpacing.xsmall,
          ),
          items: items,
        ),
      ),
    );
  }
}
